@@ -1,10 +1,10 @@
 from solana.rpc.async_api import AsyncClient
 from solana.transaction import Transaction
-from ..abstract_async_rate_limit import *
+from ..async_utils.abstract_async_rate_limit import *
 from typing import List, Dict, Any
 import asyncio
 from .utils import *
-def process_binary_data(binary_data):
+def process_binary_data(binary_data,luts=[]):
     decoded_data = binary_data.data  # Accessing the raw data directly
     addresses = decode_lut_data(decoded_data)  # Use the implemented function here
     luts.extend([get_pubString(address) for address in addresses])
@@ -40,7 +40,7 @@ async def fetch_lut_addresses(client: AsyncClient, lut_keys: List[Pubkey]) -> Li
         
         account_info = response.value
         if account_info:
-            process_binary_data(account_info)
+            process_binary_data(account_info,luts)
     return luts
 
 async def process_transaction(client: AsyncClient, txnData: Dict[str, Any]) -> List[str]:
